pub struct InherentDataProvider { /* private fields */ }Expand description
Provides the slot duration inherent data for BABE.
Implementations
Sourceimpl InherentDataProvider
impl InherentDataProvider
Sourcepub fn new(slot: InherentType) -> Self
pub fn new(slot: InherentType) -> Self
Create new inherent data provider from the given slot.
Sourcepub fn from_timestamp_and_slot_duration(
timestamp: Timestamp,
slot_duration: SlotDuration,
) -> Self
pub fn from_timestamp_and_slot_duration( timestamp: Timestamp, slot_duration: SlotDuration, ) -> Self
Creates the inherent data provider by calculating the slot from the given
timestamp and duration.
Sourcepub fn slot(&self) -> InherentType
pub fn slot(&self) -> InherentType
Returns the slot of this inherent data provider.
Methods from Deref<Target = InherentType>
Sourcepub fn timestamp(&self, slot_duration: SlotDuration) -> Option<Timestamp>
pub fn timestamp(&self, slot_duration: SlotDuration) -> Option<Timestamp>
Timestamp of the start of the slot.
Returns None if would overflow for given SlotDuration.